#include <osgText/Version>

const char* osgTextGetVersion()
{
    return "1.1";
}


const char* osgTextGetLibraryName()
{
    return "OpenSceneGraph Text Library";
}
